# coding: utf-8

"""
    Cherwell REST API

    Unofficial Python Cherwell REST API library.  # noqa: E501

    The version of the OpenAPI document: 9.3.2
    Contact: See AUTHORS.
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from pycherwell.configuration import Configuration


class SaveApiClientSettingRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'allow_anonymous_access': 'bool',
        'api_access_is_enabled': 'bool',
        'create_new_client_key': 'bool',
        'culture': 'str',
        'description': 'str',
        'name': 'str',
        'refresh_token_lifespan_minutes': 'int',
        'stand_in_key': 'str',
        'token_lifespan_minutes': 'int'
    }

    attribute_map = {
        'allow_anonymous_access': 'allowAnonymousAccess',
        'api_access_is_enabled': 'apiAccessIsEnabled',
        'create_new_client_key': 'createNewClientKey',
        'culture': 'culture',
        'description': 'description',
        'name': 'name',
        'refresh_token_lifespan_minutes': 'refreshTokenLifespanMinutes',
        'stand_in_key': 'standInKey',
        'token_lifespan_minutes': 'tokenLifespanMinutes'
    }

    def __init__(self, allow_anonymous_access=None, api_access_is_enabled=None, create_new_client_key=None, culture=None, description=None, name=None, refresh_token_lifespan_minutes=None, stand_in_key=None, token_lifespan_minutes=None, local_vars_configuration=None):  # noqa: E501
        """SaveApiClientSettingRequest - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._allow_anonymous_access = None
        self._api_access_is_enabled = None
        self._create_new_client_key = None
        self._culture = None
        self._description = None
        self._name = None
        self._refresh_token_lifespan_minutes = None
        self._stand_in_key = None
        self._token_lifespan_minutes = None
        self.discriminator = None

        if allow_anonymous_access is not None:
            self.allow_anonymous_access = allow_anonymous_access
        if api_access_is_enabled is not None:
            self.api_access_is_enabled = api_access_is_enabled
        if create_new_client_key is not None:
            self.create_new_client_key = create_new_client_key
        if culture is not None:
            self.culture = culture
        if description is not None:
            self.description = description
        if name is not None:
            self.name = name
        if refresh_token_lifespan_minutes is not None:
            self.refresh_token_lifespan_minutes = refresh_token_lifespan_minutes
        if stand_in_key is not None:
            self.stand_in_key = stand_in_key
        if token_lifespan_minutes is not None:
            self.token_lifespan_minutes = token_lifespan_minutes

    @property
    def allow_anonymous_access(self):
        """Gets the allow_anonymous_access of this SaveApiClientSettingRequest.  # noqa: E501


        :return: The allow_anonymous_access of this SaveApiClientSettingRequest.  # noqa: E501
        :rtype: bool
        """
        return self._allow_anonymous_access

    @allow_anonymous_access.setter
    def allow_anonymous_access(self, allow_anonymous_access):
        """Sets the allow_anonymous_access of this SaveApiClientSettingRequest.


        :param allow_anonymous_access: The allow_anonymous_access of this SaveApiClientSettingRequest.  # noqa: E501
        :type: bool
        """

        self._allow_anonymous_access = allow_anonymous_access

    @property
    def api_access_is_enabled(self):
        """Gets the api_access_is_enabled of this SaveApiClientSettingRequest.  # noqa: E501


        :return: The api_access_is_enabled of this SaveApiClientSettingRequest.  # noqa: E501
        :rtype: bool
        """
        return self._api_access_is_enabled

    @api_access_is_enabled.setter
    def api_access_is_enabled(self, api_access_is_enabled):
        """Sets the api_access_is_enabled of this SaveApiClientSettingRequest.


        :param api_access_is_enabled: The api_access_is_enabled of this SaveApiClientSettingRequest.  # noqa: E501
        :type: bool
        """

        self._api_access_is_enabled = api_access_is_enabled

    @property
    def create_new_client_key(self):
        """Gets the create_new_client_key of this SaveApiClientSettingRequest.  # noqa: E501


        :return: The create_new_client_key of this SaveApiClientSettingRequest.  # noqa: E501
        :rtype: bool
        """
        return self._create_new_client_key

    @create_new_client_key.setter
    def create_new_client_key(self, create_new_client_key):
        """Sets the create_new_client_key of this SaveApiClientSettingRequest.


        :param create_new_client_key: The create_new_client_key of this SaveApiClientSettingRequest.  # noqa: E501
        :type: bool
        """

        self._create_new_client_key = create_new_client_key

    @property
    def culture(self):
        """Gets the culture of this SaveApiClientSettingRequest.  # noqa: E501


        :return: The culture of this SaveApiClientSettingRequest.  # noqa: E501
        :rtype: str
        """
        return self._culture

    @culture.setter
    def culture(self, culture):
        """Sets the culture of this SaveApiClientSettingRequest.


        :param culture: The culture of this SaveApiClientSettingRequest.  # noqa: E501
        :type: str
        """

        self._culture = culture

    @property
    def description(self):
        """Gets the description of this SaveApiClientSettingRequest.  # noqa: E501


        :return: The description of this SaveApiClientSettingRequest.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this SaveApiClientSettingRequest.


        :param description: The description of this SaveApiClientSettingRequest.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def name(self):
        """Gets the name of this SaveApiClientSettingRequest.  # noqa: E501


        :return: The name of this SaveApiClientSettingRequest.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this SaveApiClientSettingRequest.


        :param name: The name of this SaveApiClientSettingRequest.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def refresh_token_lifespan_minutes(self):
        """Gets the refresh_token_lifespan_minutes of this SaveApiClientSettingRequest.  # noqa: E501


        :return: The refresh_token_lifespan_minutes of this SaveApiClientSettingRequest.  # noqa: E501
        :rtype: int
        """
        return self._refresh_token_lifespan_minutes

    @refresh_token_lifespan_minutes.setter
    def refresh_token_lifespan_minutes(self, refresh_token_lifespan_minutes):
        """Sets the refresh_token_lifespan_minutes of this SaveApiClientSettingRequest.


        :param refresh_token_lifespan_minutes: The refresh_token_lifespan_minutes of this SaveApiClientSettingRequest.  # noqa: E501
        :type: int
        """

        self._refresh_token_lifespan_minutes = refresh_token_lifespan_minutes

    @property
    def stand_in_key(self):
        """Gets the stand_in_key of this SaveApiClientSettingRequest.  # noqa: E501


        :return: The stand_in_key of this SaveApiClientSettingRequest.  # noqa: E501
        :rtype: str
        """
        return self._stand_in_key

    @stand_in_key.setter
    def stand_in_key(self, stand_in_key):
        """Sets the stand_in_key of this SaveApiClientSettingRequest.


        :param stand_in_key: The stand_in_key of this SaveApiClientSettingRequest.  # noqa: E501
        :type: str
        """

        self._stand_in_key = stand_in_key

    @property
    def token_lifespan_minutes(self):
        """Gets the token_lifespan_minutes of this SaveApiClientSettingRequest.  # noqa: E501


        :return: The token_lifespan_minutes of this SaveApiClientSettingRequest.  # noqa: E501
        :rtype: int
        """
        return self._token_lifespan_minutes

    @token_lifespan_minutes.setter
    def token_lifespan_minutes(self, token_lifespan_minutes):
        """Sets the token_lifespan_minutes of this SaveApiClientSettingRequest.


        :param token_lifespan_minutes: The token_lifespan_minutes of this SaveApiClientSettingRequest.  # noqa: E501
        :type: int
        """

        self._token_lifespan_minutes = token_lifespan_minutes

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SaveApiClientSettingRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, SaveApiClientSettingRequest):
            return True

        return self.to_dict() != other.to_dict()
