# coding: utf-8

"""
    Cherwell REST API

    Unofficial Python Cherwell REST API library.  # noqa: E501

    The version of the OpenAPI document: 9.3.2
    Contact: See AUTHORS.
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import pycherwell
from pycherwell.api.teams_api import TeamsApi  # noqa: E501
from pycherwell.rest import ApiException


class TestTeamsApi(unittest.TestCase):
    """TeamsApi unit test stubs"""

    def setUp(self):
        self.api = pycherwell.api.teams_api.TeamsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_teams_add_user_to_team_by_batch_v1(self):
        """Test case for teams_add_user_to_team_by_batch_v1

        Add users to a team by batch  # noqa: E501
        """
        pass

    def test_teams_add_user_to_team_v1(self):
        """Test case for teams_add_user_to_team_v1

        Add a user to a team  # noqa: E501
        """
        pass

    def test_teams_add_user_to_team_v2(self):
        """Test case for teams_add_user_to_team_v2

        Add a user to a team  # noqa: E501
        """
        pass

    def test_teams_delete_team_v1(self):
        """Test case for teams_delete_team_v1

        Delete a Team  # noqa: E501
        """
        pass

    def test_teams_get_team_v1(self):
        """Test case for teams_get_team_v1

        Get a team by its TeamId  # noqa: E501
        """
        pass

    def test_teams_get_teams_v1(self):
        """Test case for teams_get_teams_v1

        Get all available Teams  # noqa: E501
        """
        pass

    def test_teams_get_teams_v2(self):
        """Test case for teams_get_teams_v2

        Get all available Teams  # noqa: E501
        """
        pass

    def test_teams_get_users_teams_v1(self):
        """Test case for teams_get_users_teams_v1

        Get Team assignments for a user  # noqa: E501
        """
        pass

    def test_teams_get_users_teams_v2(self):
        """Test case for teams_get_users_teams_v2

        Get Team assignments for a user  # noqa: E501
        """
        pass

    def test_teams_get_workgroups_v1(self):
        """Test case for teams_get_workgroups_v1

        Get all available Workgroups  # noqa: E501
        """
        pass

    def test_teams_get_workgroups_v2(self):
        """Test case for teams_get_workgroups_v2

        Get all available Workgroups  # noqa: E501
        """
        pass

    def test_teams_remove_customer_from_workgroup_v1(self):
        """Test case for teams_remove_customer_from_workgroup_v1

        Remove a customer from a Workgroup  # noqa: E501
        """
        pass

    def test_teams_remove_user_from_team_v1(self):
        """Test case for teams_remove_user_from_team_v1

        Operation to remove a User from a Team.  # noqa: E501
        """
        pass

    def test_teams_remove_user_from_team_v2(self):
        """Test case for teams_remove_user_from_team_v2

        Operation to remove a User from a Team.  # noqa: E501
        """
        pass

    def test_teams_save_team_member_v1(self):
        """Test case for teams_save_team_member_v1

        Add or Update a team member  # noqa: E501
        """
        pass

    def test_teams_save_team_v1(self):
        """Test case for teams_save_team_v1

        Create or update a team  # noqa: E501
        """
        pass

    def test_teams_save_workgroup_member_v1(self):
        """Test case for teams_save_workgroup_member_v1

        Save the membership status of a Workgroup member.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
