# coding: utf-8

"""
    Cherwell REST API

    Unofficial Python Cherwell REST API library.  # noqa: E501

    The version of the OpenAPI document: 9.3.2
    Contact: See AUTHORS.
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import pycherwell
from pycherwell.api.core_api import CoreApi  # noqa: E501
from pycherwell.rest import ApiException


class TestCoreApi(unittest.TestCase):
    """CoreApi unit test stubs"""

    def setUp(self):
        self.api = pycherwell.api.core_api.CoreApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_core_delete_gallery_image_by_stand_in_key_v1(self):
        """Test case for core_delete_gallery_image_by_stand_in_key_v1

        Delete a gallery image  # noqa: E501
        """
        pass

    def test_core_get_gallery_image_v1(self):
        """Test case for core_get_gallery_image_v1

        Get built-in images  # noqa: E501
        """
        pass

    def test_core_get_gallery_images_folder_v1(self):
        """Test case for core_get_gallery_images_folder_v1

        Get gallery images by scope, scopeowner, and folder  # noqa: E501
        """
        pass

    def test_core_get_gallery_images_scope_owner_v1(self):
        """Test case for core_get_gallery_images_scope_owner_v1

        Get gallery images by scope and scopeowner  # noqa: E501
        """
        pass

    def test_core_get_gallery_images_scope_v1(self):
        """Test case for core_get_gallery_images_scope_v1

        Get gallery images by scope  # noqa: E501
        """
        pass

    def test_core_get_gallery_images_v1(self):
        """Test case for core_get_gallery_images_v1

        Get all gallery images  # noqa: E501
        """
        pass

    def test_core_get_stored_value_v1(self):
        """Test case for core_get_stored_value_v1

        Get a  stored value  # noqa: E501
        """
        pass

    def test_core_get_stored_values_folder_v1(self):
        """Test case for core_get_stored_values_folder_v1

        Get stored values by folder  # noqa: E501
        """
        pass

    def test_core_get_stored_values_scope_owner_v1(self):
        """Test case for core_get_stored_values_scope_owner_v1

        Get stored values by scope owner  # noqa: E501
        """
        pass

    def test_core_get_stored_values_scope_v1(self):
        """Test case for core_get_stored_values_scope_v1

        Get stored values by scope  # noqa: E501
        """
        pass

    def test_core_get_stored_values_v1(self):
        """Test case for core_get_stored_values_v1

        Gets all the stored values in the system  # noqa: E501
        """
        pass

    def test_core_get_views_v1(self):
        """Test case for core_get_views_v1

        Get a list of the views  # noqa: E501
        """
        pass

    def test_core_save_gallery_image_v1(self):
        """Test case for core_save_gallery_image_v1

        Create or update a gallery image  # noqa: E501
        """
        pass

    def test_core_save_stored_value_v1(self):
        """Test case for core_save_stored_value_v1

        Create or update a stored value  # noqa: E501
        """
        pass

    def test_core_set_culture_v1(self):
        """Test case for core_set_culture_v1

        Set the culture for the current user  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
