# coding: utf-8

"""
    Cherwell REST API

    Unofficial Python Cherwell REST API library.  # noqa: E501

    The version of the OpenAPI document: 9.3.2
    Contact: See AUTHORS.
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import pycherwell
from pycherwell.api.service_api import ServiceApi  # noqa: E501
from pycherwell.rest import ApiException


class TestServiceApi(unittest.TestCase):
    """ServiceApi unit test stubs"""

    def setUp(self):
        self.api = pycherwell.api.service_api.ServiceApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_service_get_service_info_v1(self):
        """Test case for service_get_service_info_v1

        Get information about the REST Api and CSM  # noqa: E501
        """
        pass

    def test_service_logout_user_v1(self):
        """Test case for service_logout_user_v1

        Log out user by token  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
