# coding: utf-8

"""
    Cherwell REST API

    Unofficial Python Cherwell REST API library.  # noqa: E501

    The version of the OpenAPI document: 9.3.2
    Contact: See AUTHORS.
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import pycherwell
from pycherwell.api.searches_api import SearchesApi  # noqa: E501
from pycherwell.rest import ApiException


class TestSearchesApi(unittest.TestCase):
    """SearchesApi unit test stubs"""

    def setUp(self):
        self.api = pycherwell.api.searches_api.SearchesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_searches_get_quick_search_configuration_for_bus_obs_v1(self):
        """Test case for searches_get_quick_search_configuration_for_bus_obs_v1

        Get a Quick Search from a list of Business Object IDs  # noqa: E501
        """
        pass

    def test_searches_get_quick_search_configuration_for_bus_obs_with_view_rights_v1(self):
        """Test case for searches_get_quick_search_configuration_for_bus_obs_with_view_rights_v1

        Get a Quick Search by Business Objects with view rights  # noqa: E501
        """
        pass

    def test_searches_get_quick_search_results_v1(self):
        """Test case for searches_get_quick_search_results_v1

        Execute a Quick Search from a list of Business Object IDs and search text  # noqa: E501
        """
        pass

    def test_searches_get_quick_search_specific_results_v1(self):
        """Test case for searches_get_quick_search_specific_results_v1

        Execute a Quick Search on a specific Business Object  # noqa: E501
        """
        pass

    def test_searches_get_quick_search_specific_results_v2(self):
        """Test case for searches_get_quick_search_specific_results_v2

        Execute a Quick Search on a specific Business Object  # noqa: E501
        """
        pass

    def test_searches_get_search_items_by_association_scope_scope_owner_folder_v1(self):
        """Test case for searches_get_search_items_by_association_scope_scope_owner_folder_v1

        Get all saved searches by Folder ID  # noqa: E501
        """
        pass

    def test_searches_get_search_items_by_association_scope_scope_owner_folder_v2(self):
        """Test case for searches_get_search_items_by_association_scope_scope_owner_folder_v2

        Get all saved searches by Folder ID  # noqa: E501
        """
        pass

    def test_searches_get_search_items_by_association_scope_scope_owner_v1(self):
        """Test case for searches_get_search_items_by_association_scope_scope_owner_v1

        Get all saved searches by scope owner (sub scope)  # noqa: E501
        """
        pass

    def test_searches_get_search_items_by_association_scope_scope_owner_v2(self):
        """Test case for searches_get_search_items_by_association_scope_scope_owner_v2

        Get all saved searches by scope owner (sub scope)  # noqa: E501
        """
        pass

    def test_searches_get_search_items_by_association_scope_v1(self):
        """Test case for searches_get_search_items_by_association_scope_v1

        Get all saved searches by scope  # noqa: E501
        """
        pass

    def test_searches_get_search_items_by_association_scope_v2(self):
        """Test case for searches_get_search_items_by_association_scope_v2

        Get all saved searches by scope  # noqa: E501
        """
        pass

    def test_searches_get_search_items_by_association_v1(self):
        """Test case for searches_get_search_items_by_association_v1

        Get all saved searches by Business Object association  # noqa: E501
        """
        pass

    def test_searches_get_search_items_by_association_v2(self):
        """Test case for searches_get_search_items_by_association_v2

        Get all saved searches by Business Object association  # noqa: E501
        """
        pass

    def test_searches_get_search_items_v1(self):
        """Test case for searches_get_search_items_v1

        Get all saved searches by default Business Object association  # noqa: E501
        """
        pass

    def test_searches_get_search_items_v2(self):
        """Test case for searches_get_search_items_v2

        Get all saved searches by default Business Object association  # noqa: E501
        """
        pass

    def test_searches_get_search_results_ad_hoc_v1(self):
        """Test case for searches_get_search_results_ad_hoc_v1

        Run an ad-hoc search  # noqa: E501
        """
        pass

    def test_searches_get_search_results_by_id_v1(self):
        """Test case for searches_get_search_results_by_id_v1

        Run a saved search by internal ID  # noqa: E501
        """
        pass

    def test_searches_get_search_results_by_name_v1(self):
        """Test case for searches_get_search_results_by_name_v1

        Run a saved search by name  # noqa: E501
        """
        pass

    def test_searches_get_search_results_export_ad_hoc_v1(self):
        """Test case for searches_get_search_results_export_ad_hoc_v1

        Export an ad-hoc search  # noqa: E501
        """
        pass

    def test_searches_get_search_results_export_by_id_v1(self):
        """Test case for searches_get_search_results_export_by_id_v1

        Export a saved search by ID  # noqa: E501
        """
        pass

    def test_searches_get_search_results_export_by_name_v1(self):
        """Test case for searches_get_search_results_export_by_name_v1

        Export a saved search by name  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
