# coding: utf-8

"""
    Cherwell REST API

    Unofficial Python Cherwell REST API library.  # noqa: E501

    The version of the OpenAPI document: 9.3.2
    Contact: See AUTHORS.
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import pycherwell
from pycherwell.api.business_object_api import BusinessObjectApi  # noqa: E501
from pycherwell.rest import ApiException


class TestBusinessObjectApi(unittest.TestCase):
    """BusinessObjectApi unit test stubs"""

    def setUp(self):
        self.api = pycherwell.api.business_object_api.BusinessObjectApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_business_object_delete_business_object_batch_v1(self):
        """Test case for business_object_delete_business_object_batch_v1

        Delete Business Objects in a batch  # noqa: E501
        """
        pass

    def test_business_object_delete_business_object_by_public_id_v1(self):
        """Test case for business_object_delete_business_object_by_public_id_v1

        Delete a Business Object by public ID  # noqa: E501
        """
        pass

    def test_business_object_delete_business_object_by_rec_id_v1(self):
        """Test case for business_object_delete_business_object_by_rec_id_v1

        Delete a Business Object by record ID  # noqa: E501
        """
        pass

    def test_business_object_delete_related_business_object_by_public_id_v1(self):
        """Test case for business_object_delete_related_business_object_by_public_id_v1

        Delete a related Business Object by public ID  # noqa: E501
        """
        pass

    def test_business_object_delete_related_business_object_by_rec_id_v1(self):
        """Test case for business_object_delete_related_business_object_by_rec_id_v1

        Delete a related Business Object by record ID  # noqa: E501
        """
        pass

    def test_business_object_field_values_lookup_v1(self):
        """Test case for business_object_field_values_lookup_v1

        Get lookup values for fields  # noqa: E501
        """
        pass

    def test_business_object_get_business_object_attachment_by_attachment_id_v1(self):
        """Test case for business_object_get_business_object_attachment_by_attachment_id_v1

        Get an imported Business Object attachment  # noqa: E501
        """
        pass

    def test_business_object_get_business_object_attachments_by_id_and_public_id_v1(self):
        """Test case for business_object_get_business_object_attachments_by_id_and_public_id_v1

        Get attachments by Business Object public ID  # noqa: E501
        """
        pass

    def test_business_object_get_business_object_attachments_by_id_and_rec_id_v1(self):
        """Test case for business_object_get_business_object_attachments_by_id_and_rec_id_v1

        Get attachments by Business Object record ID  # noqa: E501
        """
        pass

    def test_business_object_get_business_object_attachments_by_name_and_public_id_v1(self):
        """Test case for business_object_get_business_object_attachments_by_name_and_public_id_v1

        Get attachments by Business Object name and public ID  # noqa: E501
        """
        pass

    def test_business_object_get_business_object_attachments_by_name_and_rec_id_v1(self):
        """Test case for business_object_get_business_object_attachments_by_name_and_rec_id_v1

        Get attachments by Business Object name and record ID  # noqa: E501
        """
        pass

    def test_business_object_get_business_object_attachments_v1(self):
        """Test case for business_object_get_business_object_attachments_v1

        Get Business Object attachments by request object  # noqa: E501
        """
        pass

    def test_business_object_get_business_object_batch_v1(self):
        """Test case for business_object_get_business_object_batch_v1

        Get a batch of Business Object records  # noqa: E501
        """
        pass

    def test_business_object_get_business_object_by_public_id_v1(self):
        """Test case for business_object_get_business_object_by_public_id_v1

        Get a Business Object record  # noqa: E501
        """
        pass

    def test_business_object_get_business_object_by_rec_id_v1(self):
        """Test case for business_object_get_business_object_by_rec_id_v1

        Get a Business Object record  # noqa: E501
        """
        pass

    def test_business_object_get_business_object_by_scan_code_bus_ob_id_v1(self):
        """Test case for business_object_get_business_object_by_scan_code_bus_ob_id_v1

        Get a Business Object by its scan code and Business Object ID  # noqa: E501
        """
        pass

    def test_business_object_get_business_object_by_scan_code_bus_ob_name_v1(self):
        """Test case for business_object_get_business_object_by_scan_code_bus_ob_name_v1

        Get a Business Object by its scan code and Business Object name  # noqa: E501
        """
        pass

    def test_business_object_get_business_object_schema_v1(self):
        """Test case for business_object_get_business_object_schema_v1

        Get a Business Object schema  # noqa: E501
        """
        pass

    def test_business_object_get_business_object_summaries_v1(self):
        """Test case for business_object_get_business_object_summaries_v1

        Get Business Object summaries by type  # noqa: E501
        """
        pass

    def test_business_object_get_business_object_summary_by_id_v1(self):
        """Test case for business_object_get_business_object_summary_by_id_v1

        Get a Business Object summary by ID  # noqa: E501
        """
        pass

    def test_business_object_get_business_object_summary_by_name_v1(self):
        """Test case for business_object_get_business_object_summary_by_name_v1

        Get a Business Object summary by name  # noqa: E501
        """
        pass

    def test_business_object_get_business_object_template_v1(self):
        """Test case for business_object_get_business_object_template_v1

        Get Business Object templates for create  # noqa: E501
        """
        pass

    def test_business_object_get_related_business_object_by_request_v1(self):
        """Test case for business_object_get_related_business_object_by_request_v1

        Get related Business Objects using a request object  # noqa: E501
        """
        pass

    def test_business_object_get_related_business_object_v1(self):
        """Test case for business_object_get_related_business_object_v1

        Get related Business Objects by ID  # noqa: E501
        """
        pass

    def test_business_object_get_related_business_object_with_custom_grid_v1(self):
        """Test case for business_object_get_related_business_object_with_custom_grid_v1

        Get related Business Objects custom grid  # noqa: E501
        """
        pass

    def test_business_object_link_related_business_object_by_rec_id_v1(self):
        """Test case for business_object_link_related_business_object_by_rec_id_v1

        Link related Business Objects  # noqa: E501
        """
        pass

    def test_business_object_remove_business_object_attachment_by_id_and_public_id_v1(self):
        """Test case for business_object_remove_business_object_attachment_by_id_and_public_id_v1

        Remove an attachment by Business Object ID and public ID  # noqa: E501
        """
        pass

    def test_business_object_remove_business_object_attachment_by_id_and_rec_id_v1(self):
        """Test case for business_object_remove_business_object_attachment_by_id_and_rec_id_v1

        Remove an attachment by Business Object ID and record ID  # noqa: E501
        """
        pass

    def test_business_object_remove_business_object_attachment_by_name_and_public_id_v1(self):
        """Test case for business_object_remove_business_object_attachment_by_name_and_public_id_v1

        Remove an attachment by Business Object name and public ID  # noqa: E501
        """
        pass

    def test_business_object_remove_business_object_attachment_by_name_and_rec_id_v1(self):
        """Test case for business_object_remove_business_object_attachment_by_name_and_rec_id_v1

        Remove an attachment by Business Object name and record ID  # noqa: E501
        """
        pass

    def test_business_object_save_business_object_attachment_bus_ob_v1(self):
        """Test case for business_object_save_business_object_attachment_bus_ob_v1

        Attach a Business Object to a Business Object  # noqa: E501
        """
        pass

    def test_business_object_save_business_object_attachment_link_v1(self):
        """Test case for business_object_save_business_object_attachment_link_v1

        Attach a file via UNC  # noqa: E501
        """
        pass

    def test_business_object_save_business_object_attachment_url_v1(self):
        """Test case for business_object_save_business_object_attachment_url_v1

        Attach a URL path  # noqa: E501
        """
        pass

    def test_business_object_save_business_object_batch_v1(self):
        """Test case for business_object_save_business_object_batch_v1

        Create or update a batch of Business Objects  # noqa: E501
        """
        pass

    def test_business_object_save_business_object_v1(self):
        """Test case for business_object_save_business_object_v1

        Create or Update a Business Object  # noqa: E501
        """
        pass

    def test_business_object_save_related_business_object_v1(self):
        """Test case for business_object_save_related_business_object_v1

        Create or update a related Business Object  # noqa: E501
        """
        pass

    def test_business_object_un_link_related_business_object_by_rec_id_v1(self):
        """Test case for business_object_un_link_related_business_object_by_rec_id_v1

        UnLink related Business Objects  # noqa: E501
        """
        pass

    def test_business_object_upload_business_object_attachment_by_id_and_public_id_v1(self):
        """Test case for business_object_upload_business_object_attachment_by_id_and_public_id_v1

        Upload an attachment by Business Object ID and public ID  # noqa: E501
        """
        pass

    def test_business_object_upload_business_object_attachment_by_id_and_rec_id_v1(self):
        """Test case for business_object_upload_business_object_attachment_by_id_and_rec_id_v1

        Upload an attachment by Business Object ID and record ID  # noqa: E501
        """
        pass

    def test_business_object_upload_business_object_attachment_by_name_and_public_id_v1(self):
        """Test case for business_object_upload_business_object_attachment_by_name_and_public_id_v1

        Upload an attachment by Business Object name and public ID  # noqa: E501
        """
        pass

    def test_business_object_upload_business_object_attachment_by_name_and_rec_id_v1(self):
        """Test case for business_object_upload_business_object_attachment_by_name_and_rec_id_v1

        Upload an attachment by Business Object name and record ID  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
