# coding: utf-8

"""
    Cherwell REST API

    Unofficial Python Cherwell REST API library.  # noqa: E501

    The version of the OpenAPI document: 9.3.2
    Contact: See AUTHORS.
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import pycherwell
from pycherwell.models.stored_value_response import StoredValueResponse  # noqa: E501
from pycherwell.rest import ApiException


class TestStoredValueResponse(unittest.TestCase):
    """StoredValueResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testStoredValueResponse(self):
        """Test StoredValueResponse"""
        # FIXME: construct object with mandatory attributes with example values
        # model = pycherwell.models.stored_value_response.StoredValueResponse()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
