# coding: utf-8

"""
    Cherwell REST API

    Unofficial Python Cherwell REST API library.  # noqa: E501

    The version of the OpenAPI document: 9.3.2
    Contact: See AUTHORS.
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import pycherwell
from pycherwell.api.users_api import UsersApi  # noqa: E501
from pycherwell.rest import ApiException


class TestUsersApi(unittest.TestCase):
    """UsersApi unit test stubs"""

    def setUp(self):
        self.api = pycherwell.api.users_api.UsersApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_users_delete_user_batch_v1(self):
        """Test case for users_delete_user_batch_v1

        Delete a batch of users  # noqa: E501
        """
        pass

    def test_users_delete_user_batch_v2(self):
        """Test case for users_delete_user_batch_v2

        Delete a batch of users  # noqa: E501
        """
        pass

    def test_users_delete_user_v1(self):
        """Test case for users_delete_user_v1

        Delete a user by record ID  # noqa: E501
        """
        pass

    def test_users_delete_user_v2(self):
        """Test case for users_delete_user_v2

        Delete a user by record ID  # noqa: E501
        """
        pass

    def test_users_get_list_of_users(self):
        """Test case for users_get_list_of_users

        Get a list of all system users.  # noqa: E501
        """
        pass

    def test_users_get_user_batch_v1(self):
        """Test case for users_get_user_batch_v1

        Get user information in a batch  # noqa: E501
        """
        pass

    def test_users_get_user_by_login_id_v1(self):
        """Test case for users_get_user_by_login_id_v1

        Get a user by login ID  # noqa: E501
        """
        pass

    def test_users_get_user_by_login_id_v2(self):
        """Test case for users_get_user_by_login_id_v2

        Get a user by login ID and login ID type  # noqa: E501
        """
        pass

    def test_users_get_user_by_login_id_v3(self):
        """Test case for users_get_user_by_login_id_v3

        Get a user by login ID and login ID type  # noqa: E501
        """
        pass

    def test_users_get_user_by_public_id_v1(self):
        """Test case for users_get_user_by_public_id_v1

        Get a user by public ID  # noqa: E501
        """
        pass

    def test_users_get_user_by_public_id_v2(self):
        """Test case for users_get_user_by_public_id_v2

        Get a user by public ID  # noqa: E501
        """
        pass

    def test_users_get_user_by_rec_id(self):
        """Test case for users_get_user_by_rec_id

        Get a user by record ID  # noqa: E501
        """
        pass

    def test_users_save_user_batch_v1(self):
        """Test case for users_save_user_batch_v1

        Create or update users in a batch  # noqa: E501
        """
        pass

    def test_users_save_user_batch_v2(self):
        """Test case for users_save_user_batch_v2

        Create or update users in a batch  # noqa: E501
        """
        pass

    def test_users_save_user_v1(self):
        """Test case for users_save_user_v1

        Create or update a user  # noqa: E501
        """
        pass

    def test_users_save_user_v2(self):
        """Test case for users_save_user_v2

        Create or update a user  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
