# coding: utf-8

"""
    Cherwell REST API

    Unofficial Python Cherwell REST API library.  # noqa: E501

    The version of the OpenAPI document: 9.3.2
    Contact: See AUTHORS.
    Generated by: https://openapi-generator.tech
"""


from setuptools import setup, find_packages  # noqa: H301
from os import path


# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools

__version__ = '1.0.9'

this_directory = path.abspath(path.dirname(__file__))
try:
    with open(path.join(this_directory, 'README.md'), encoding='utf-8') as f:
        long_description = f.read()
except:
    with open(path.join(this_directory, 'README.md')) as f:
        long_description = f.read()

REQUIRES = ["urllib3 >= 1.15", "six >= 1.10", "certifi", "python-dateutil", "requests"]

setup(
    name='pycherwell',
    version=__version__,
    description="Cherwell REST API Client and Library",
    author="Paul Greenberg",
    author_email="greenpau@outlook.com",
    url="https://github.com/greenpau/pycherwell",
    keywords=["OpenAPI", "OpenAPI-Generator", "Cherwell REST API"],
    install_requires=REQUIRES,
    packages=find_packages(exclude=["test", "tests"]),
    scripts=['cherwell-client'],
    include_package_data=True,
    long_description=long_description,
    long_description_content_type='text/markdown'
)
