# coding: utf-8

"""
    Cherwell REST API

    Unofficial Python Cherwell REST API library.  # noqa: E501

    The version of the OpenAPI document: 9.3.2
    Contact: See AUTHORS.
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from pycherwell.configuration import Configuration


class SaveWorkgroupMemberRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'customer_record_id': 'str',
        'workgroup_id': 'str',
        'customer_is_workgroup_manager': 'bool'
    }

    attribute_map = {
        'customer_record_id': 'customerRecordId',
        'workgroup_id': 'workgroupId',
        'customer_is_workgroup_manager': 'customerIsWorkgroupManager'
    }

    def __init__(self, customer_record_id=None, workgroup_id=None, customer_is_workgroup_manager=None, local_vars_configuration=None):  # noqa: E501
        """SaveWorkgroupMemberRequest - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._customer_record_id = None
        self._workgroup_id = None
        self._customer_is_workgroup_manager = None
        self.discriminator = None

        if customer_record_id is not None:
            self.customer_record_id = customer_record_id
        if workgroup_id is not None:
            self.workgroup_id = workgroup_id
        if customer_is_workgroup_manager is not None:
            self.customer_is_workgroup_manager = customer_is_workgroup_manager

    @property
    def customer_record_id(self):
        """Gets the customer_record_id of this SaveWorkgroupMemberRequest.  # noqa: E501


        :return: The customer_record_id of this SaveWorkgroupMemberRequest.  # noqa: E501
        :rtype: str
        """
        return self._customer_record_id

    @customer_record_id.setter
    def customer_record_id(self, customer_record_id):
        """Sets the customer_record_id of this SaveWorkgroupMemberRequest.


        :param customer_record_id: The customer_record_id of this SaveWorkgroupMemberRequest.  # noqa: E501
        :type: str
        """

        self._customer_record_id = customer_record_id

    @property
    def workgroup_id(self):
        """Gets the workgroup_id of this SaveWorkgroupMemberRequest.  # noqa: E501


        :return: The workgroup_id of this SaveWorkgroupMemberRequest.  # noqa: E501
        :rtype: str
        """
        return self._workgroup_id

    @workgroup_id.setter
    def workgroup_id(self, workgroup_id):
        """Sets the workgroup_id of this SaveWorkgroupMemberRequest.


        :param workgroup_id: The workgroup_id of this SaveWorkgroupMemberRequest.  # noqa: E501
        :type: str
        """

        self._workgroup_id = workgroup_id

    @property
    def customer_is_workgroup_manager(self):
        """Gets the customer_is_workgroup_manager of this SaveWorkgroupMemberRequest.  # noqa: E501


        :return: The customer_is_workgroup_manager of this SaveWorkgroupMemberRequest.  # noqa: E501
        :rtype: bool
        """
        return self._customer_is_workgroup_manager

    @customer_is_workgroup_manager.setter
    def customer_is_workgroup_manager(self, customer_is_workgroup_manager):
        """Sets the customer_is_workgroup_manager of this SaveWorkgroupMemberRequest.


        :param customer_is_workgroup_manager: The customer_is_workgroup_manager of this SaveWorkgroupMemberRequest.  # noqa: E501
        :type: bool
        """

        self._customer_is_workgroup_manager = customer_is_workgroup_manager

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SaveWorkgroupMemberRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, SaveWorkgroupMemberRequest):
            return True

        return self.to_dict() != other.to_dict()
